# Generated by roxygen2: do not edit by hand

S3method(print,dfdr_tbl)
export(as_dfdr_tbl)
export(dfdr_bh_diagnostics)
export(dfdr_bh_elasticity)
export(dfdr_curve_stability)
export(dfdr_elasticity)
export(dfdr_equal_chance_qbands)
export(dfdr_headline)
export(dfdr_local_tail)
export(dfdr_p_calibration)
export(dfdr_pep_decoy_sanity)
export(dfdr_pep_reliability)
export(dfdr_pep_reliability_tdc)
export(dfdr_pi0_storey)
export(dfdr_plot_bh_elasticity)
export(dfdr_plot_cv)
export(dfdr_plot_dalpha)
export(dfdr_plot_dwin)
export(dfdr_plot_elasticity)
export(dfdr_plot_equal_chance)
export(dfdr_plot_fdrhat_pi0)
export(dfdr_plot_p_calibration)
export(dfdr_plot_p_calibration2)
export(dfdr_plot_p_density_by_decoy)
export(dfdr_plot_pep_density_by_decoy)
export(dfdr_plot_pep_reliability)
export(dfdr_plot_pep_reliability_tdc)
export(dfdr_plot_pi0)
export(dfdr_plot_scope_disagreement_matrix)
export(dfdr_plot_score_distributions)
export(dfdr_render_report)
export(dfdr_run_all)
export(dfdr_run_jaccard)
export(dfdr_scope_disagreement)
export(dfdr_summary_headline)
export(dfdr_sumpep)
export(dfdr_write_manifest)
export(dfdr_write_readme)
export(dfdr_write_report)
export(diann_global_minrunq)
export(diann_global_precursor)
export(diann_runxprecursor)
export(flag_headline)
export(mokapot_competed_universe)
export(read_dfdr_maxquant_msms)
export(read_dfdr_mzid)
export(read_diann_parquet)
export(read_mokapot_psms)
export(read_spectronaut)
export(read_spectronaut_efficient)
export(score_to_pvalue)
export(spectronaut_runxprecursor)
importFrom(dplyr,filter)
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(tibble,tibble)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_parent)
