utils::globalVariables(c(
  ".data",
  # common column names referenced non-standardly
  "alpha","D_alpha","CV_hat","D_alpha_win","jaccard",
  "pep","pep_mean","decoy_rate","decoy_frac","q_mean","qbin",
  "n","n_decoy","bin",
  "id","run","score","spectrum_id","precursor","is_target","is_decoy"
))
