% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_spectronaut_normalEG.R
\name{spectronaut_recompute_q_from_score}
\alias{spectronaut_recompute_q_from_score}
\title{Recompute q-values from scores using target-decoy competition}
\usage{
spectronaut_recompute_q_from_score(df)
}
\arguments{
\item{df}{Data frame with columns: is_decoy, score}
}
\value{
Data frame with added column: q_from_score
}
\description{
When Spectronaut exports NaN q-values for decoys, we can recompute them
from scores. Higher scores are better (more confident).
}
\keyword{internal}
