% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pvalue_helpers.R
\name{.safe_df}
\alias{.safe_df}
\title{Internal: validate data-frame input}
\usage{
.safe_df(x)
}
\arguments{
\item{x}{Object to check.}
}
\value{
Returns \code{x} unchanged if it is a data.frame; otherwise throws an error.
}
\description{
Asserts that \code{x} is a data.frame (including tibble). Used to provide a
consistent error message for user-facing functions that accept data frames.
}
\keyword{internal}
